==> akonadiconsole-17.04.2.tar.xz: akonadiconsole-17.04.2/src/dbconsole.h <==
/*
    Copyright (c) 2009 Volker Krause <vkrause@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef AKONADICONSOLE_DBCONSOLE_H
#define AKONADICONSOLE_DBCONSOLE_H

#include <QWidget>
#include "ui_dbconsoletab.h"

class QSqlQueryModel;
class QTabWidget;

class DbConsoleTab;

class DbConsole : public QWidget
{
    Q_OBJECT
public:
    explicit DbConsole(QWidget *parent = nullptr);

private Q_SLOTS:
    DbConsoleTab *addTab();
    void saveQueries();

private:
    int mTabCounter;
    QTabWidget *mTabWidget;
};

class DbConsoleTab : public QWidget
{
    Q_OBJECT
public:
    explicit DbConsoleTab(int index, QWidget *parent = nullptr);

    void setQuery(const QString &query);
    QString query() const;

Q_SIGNALS:
    void saveQueries();

private Q_SLOTS:
    void execClicked();
    void copyCell();

private:
    Ui::DbConsoleTab ui;
    QSqlQueryModel *mQueryModel;
    int mIndex;
};

#endif

==> akonadiconsole-17.12.1.tar.xz: akonadiconsole-17.12.1/src/dbconsole.h <==
/*
    Copyright (c) 2009 Volker Krause <vkrause@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef AKONADICONSOLE_DBCONSOLE_H
#define AKONADICONSOLE_DBCONSOLE_H

#include <QWidget>
#include "ui_dbconsoletab.h"

class QSqlQueryModel;
class QTabWidget;

class DbConsoleTab;

class DbConsole : public QWidget
{
    Q_OBJECT
public:
    explicit DbConsole(QWidget *parent = nullptr);

private Q_SLOTS:
    DbConsoleTab *addTab();
    void saveQueries();

private:
    int mTabCounter;
    QTabWidget *mTabWidget = nullptr;
};

class DbConsoleTab : public QWidget
{
    Q_OBJECT
public:
    explicit DbConsoleTab(int index, QWidget *parent = nullptr);

    void setQuery(const QString &query);
    QString query() const;

Q_SIGNALS:
    void saveQueries();

private Q_SLOTS:
    void execClicked();
    void copyCell();

private:
    Ui::DbConsoleTab ui;
    QSqlQueryModel *mQueryModel = nullptr;
    int mIndex;
};

#endif
